package mako5.gfx;


/**
 * A generic image interface. Provides the ability to render, resize, and
 * destroy an image as appropriate.
 * 
 * @author Paul Jarrett
 * @version 04-Jun 2006
 */

public interface Image {

	/**
	 * Draws this image to the screen. The image is drawn so that the top left
	 * corner of the image is at the desired location. Destroyed images have no
	 * image data and therefore cannot be rendered.
	 * 
	 * @param x_
	 *            the x-coordinate to render at
	 * @param y_
	 *            the y-coordinate to render at
	 */
	public void render(float x_, float y_);



	/**
	 * Draws this image to the screen such that it is centered at the given
	 * location.
	 * 
	 * @param x_
	 *            the x-coordinate to render at
	 * @param y_
	 *            the y-coordinate to render at
	 * @since 30-Jun 2006
	 */
	public void renderAt(float x_, float y_);



	/**
	 * Attempts to reclaim image memory components. Note that this makes the
	 * image unusable afterwards.
	 * 
	 * @return true if succeeds, false otherwise
	 */
	public boolean destroy();



	/**
	 * Used to determine if this image has been destroyed.
	 * 
	 * @return true if this image is destroyed
	 */
	public boolean isDestroyed();



	/**
	 * Attempts to resize this image.
	 * 
	 * @param width_
	 *            the new image width
	 * @param height_
	 *            the new image height
	 * @return true if the operation is successful.
	 */
	public boolean resize(int width_, int height_);



	/**
	 * Accessor method for the width of this image.
	 * 
	 * @return the width of this image
	 */
	public int getWidth();



	/**
	 * Accessor method for the height of this image.
	 * 
	 * @return the height of this image
	 */
	public int getHeight();
}