package mako5.gfx;


import mako5.gfx.j2d.JImageUtils;

/**
 * This class loads images of different types of files. Essentially, ImageLoader
 * is a facade for the entire image input subsystem.
 * 
 * @author Paul Jarrett
 * @version 29-Jun 2006
 */

public class ImageLoader {

	/**
	 * Loads an image from the given file.
	 * 
	 * Make sure that the file has the width and height of powers of 2.
	 * 
	 * @return the image or "null" if the image cannot be loaded
	 * @since 29-Jun 2006
	 */
	public static DefaultImage loadDefaultImage(String file_) {
		try {
			// original loading from file uses this
			java.awt.Image source;

			// in-between step between loading and an actual OpenGL image source
			java.awt.image.BufferedImage middleman;

			// the openGL image reference
			int glImage;

			// dimensions for the image
			int width, height;

			source = JImageUtils.load(file_);
			middleman = JImageUtils.convertToBufferedImage(source,
					java.awt.image.BufferedImage.TYPE_4BYTE_ABGR);
			glImage = JImageUtils.convertToOpenGL(middleman);

			// gets the dimensions for the image
			width = middleman.getWidth();
			height = middleman.getHeight();

			// destroy old images
			source.flush();
			source = null;
			middleman.flush();
			middleman = null;

			return new DefaultImage(width, height, glImage);
		} catch (Exception excp) {
			return null;
		}
	}



	/**
	 * Loads a masked image from the given file.
	 * 
	 * @return the image or "null" if the image cannot be loaded
	 * @since 29-Jun 2006
	 */
	public static MaskedImage loadMaskedImage(String file_, String mask_) {
		try {
			// original loading from file uses this
			java.awt.Image source;

			// in-between step between loading and an actual OpenGL image source
			java.awt.image.BufferedImage middleman;

			// the openGL image reference
			int glImage;

			// the mask reference
			int mskImage;

			// dimensions for the image
			int width, height;

			source = JImageUtils.load(file_);
			middleman = JImageUtils.convertToBufferedImage(source,
					java.awt.image.BufferedImage.TYPE_4BYTE_ABGR);
			glImage = JImageUtils.convertToOpenGL(middleman);

			// gets the dimensions for the image
			width = middleman.getWidth();
			height = middleman.getHeight();

			// makes the mask
			source = JImageUtils.load(mask_);
			middleman = JImageUtils.convertToBufferedImage(source,
					java.awt.image.BufferedImage.TYPE_4BYTE_ABGR);
			mskImage = JImageUtils.convertToOpenGL(middleman);

			// destroy old images
			source.flush();
			source = null;
			middleman.flush();
			middleman = null;
			return new MaskedImage(width, height, glImage, mskImage);
		} catch (Exception excp) {
			return null;
		}
	}



	/**
	 * Loads an image from the given file.
	 * 
	 * @return the image or "null" if the image cannot be loaded
	 * @since 29-Jun 2006
	 */
	public static Image load(String file_) {
		try {
			// original loading from file uses this
			java.awt.Image source;

			// in-between step between loading and an actual OpenGL image source
			java.awt.image.BufferedImage middleman;

			// the openGL image reference
			int glImage;

			// dimensions for the image
			int width, height;

			source = JImageUtils.load(file_);
			middleman = JImageUtils.convertToBufferedImage(source,
					java.awt.image.BufferedImage.TYPE_4BYTE_ABGR);
			glImage = JImageUtils.convertToOpenGL(middleman);

			// gets the dimensions for the image
			width = middleman.getWidth();
			height = middleman.getHeight();

			// destroy old images
			source.flush();
			source = null;
			middleman.flush();
			middleman = null;

			return new DefaultImage(width, height, glImage);
		} catch (Exception excp) {
			return null;
		}
	}
}