package mako5.gfx.d2d.grph;


import java.util.List;
import mako5.gfx.Render;

/**
 * A group of renderable objects.
 * 
 * This implementation allows flexible use of any type of list to add or remove
 * objects. Simply create the ViewGroup with whatever list type you want. For
 * example, ViewGroup group = new ViewGroup(new LinkedList<Render>());
 * 
 * @author Paul Jarrett
 * @version 04-Mar 2006
 */

public class ViewGroup implements Render {

	private List<Render> m_rObjects; // renderable objects held by this



	/**
	 * Makes a new viewgroup with the given list to put objects into.
	 * 
	 * @param rList_
	 *            the list reference to put objects into
	 * @since 05-Mar 2006
	 */
	public ViewGroup(List<Render> rList_) {
		m_rObjects = rList_;
	}



	/**
	 * Adds an object to this view group.
	 * 
	 * @param rObject_
	 *            the object to add to this group
	 * @since 05-Mar 2006
	 */
	public void add(Render rObject_) {
		m_rObjects.add(rObject_);
	}



	/**
	 * Removes an object from this view group.
	 * 
	 * @param rObject_
	 *            the object to remove
	 * @since 05-Mar 2006
	 */
	public void remove(Render rObject_) {
		m_rObjects.remove(rObject_);
	}



	/**
	 * Clears this view group of all objects.
	 * 
	 * @since 05-Mar 2006
	 */
	public void clear() {
		m_rObjects.clear();
	}



	/**
	 * Renders this view group.
	 * 
	 * @since 05-Mar 2006
	 */
	public void render() {
		// render all objects contained by this
		for (Render r : m_rObjects) {
			r.render();
		}
	}
}