package mako5.math;


/**
 * Represents a set of polar coordinates.
 * 
 * Can be used to represent velocity and other things as well.
 * 
 * 
 * @author Paul Jarrett
 * @version 1-Feb 2006
 * @version 1-Jul 2006
 * @version 01-Aug 2006
 */

public final class Polar implements Cloneable {

	private float m_fRadius; // the radius

	private Angle m_rTheta; // the angle for this polar



	/**
	 * Creates a new polar set
	 */
	public Polar(float fRadius_, float fTheta_) {
		m_fRadius = fRadius_;
		m_rTheta = new Angle(fTheta_);
	}



	/**
	 * Another polar constructor.
	 * 
	 * Makes a polar value of (1.0f,0.0f).
	 */
	public Polar() {
		this(1.0f, 0.0f);
	}



	/**
	 * Clones this polar value.
	 */
	@Override
	public Object clone() {
		return new Polar(getRadius(), getTheta().toRadians());
	}



	/**
	 * Returns the radius
	 * @since 01-Aug 2006
	 */
	public float getRadius() {
		return m_fRadius;
	}



	/**
	 * Returns the angle of this
	 * @since 01-Aug 2006
	 */
	public Angle getTheta() {
		return m_rTheta;
	}



	/**
	 * Sets the radius of the polar value.
	 * @since 01-Aug 2006
	 */
	public void setRadius(float f) {
		m_fRadius = f;
	}



	/**
	 * Sets the theta value.
	 * 
	 * @param f the new theta value in radians
	 * 
	 * @since 05-Jul 2006
	 */
	public void setTheta(float f) {
		m_rTheta.setRadians(f);
	}


	
	/**
	 * Adds to the theta value.
	 * @param f the amount to add in radians
	 * @since 01-Aug 2006
	 */
	public void addTheta(float f) {
		m_rTheta.addRadians(f);
	}
	
	
	/**
	 * Adds to the radius of this polar value.
	 * @param v the amount to add
	 * @since 01-Aug 2006
	 */
	public void addRadius(float v) {
		m_fRadius += v;
	}
	
	

	/**
	 * Returns the x-coordinate value of this.
	 */
	public float getX() {
		return m_fRadius * (float) (Math.cos(m_rTheta.toRadians()));
	}



	/**
	 * Returns the y-coordinate of this.
	 */
	public float getY() {
		return m_fRadius * (float) Math.sin(m_rTheta.toRadians());
	}



	/**
	 * Converts this to a vector
	 */
	public R2v toVector() {
		return new R2v(getX(), getY());
	}
}