package mako5.math;


/**
 * Handles trigonometry.
 * 
 * @author Paul Jarrett
 * @since 03-Apr 2006
 */

public class Trig {

	// finds the factorial of the given value
	public static double fact(int val) {
		if ((val == 0) || (val == 1)) {
			return 1;
		} else {
			return val * fact(val - 1);
		}
	}



	// finds the sine of the value
	// steps: number of iterators of the maclaurin series to use
	public static double sine(double val, int steps) {
		assert (steps > 0);

		double x_2n1; // x^(2 * n + 1)
		double n2_1f; // (2 * n + 1)!
		double _1neg; // (-1)^n

		double term; // the current term
		double sum; // the total sum

		x_2n1 = 1.0;
		n2_1f = 1.0;
		_1neg = 1.0;

		sum = 0;

		// perform the number of iterations that we want
		for (int i = 0; i < steps; i++) {
			x_2n1 = Math.pow(val, 2 * i + 1);
			n2_1f = fact(2 * i + 1);

			// gets the current term
			term = (_1neg * (x_2n1 / n2_1f));

			// flip the sign of the next term
			_1neg *= -1.0;

			// add the term to the sum
			sum += term;
		}

		// returns the sum
		return sum;
	}



	// my own cosine function
	// x - the value to find cos for
	// steps - the number of steps of precision
	public static double cosine(double x, int steps) {
		assert (steps > 0); // makes sure that the number of steps is > 0

		double sum; // the current sum
		double x_2n; // the value of x^2n
		double fact_2n; // the value of (2n)!
		double term; // the current term

		sum = 1;
		x_2n = 1;

		for (int n = 1; n < steps; n++) {
			// x_2n = pow(x, 2*n);
			x_2n *= x * x;

			fact_2n = fact(2 * n);

			term = x_2n / fact_2n;

			term *= ((n & 1) == 1) ? -1 : 1;

			sum += term;
		}

		return sum;
	}
}