package mako5.math.phys;


import mako5.math.R2v;

/**
 * Bounds shaped like a circle.
 * 
 * @author Paul Jarrett
 * @version 17-Feb 2006
 */

public class BoundingCircle extends Bounds {

	private float m_fRadius; // m_fRadius of this bounds object



	/**
	 * Creates a new BoundingCircle.
	 */
	public BoundingCircle(float fRadius_) {
		super(Bounds.CIRCLE);

		// sets the radius
		setRadius(fRadius_);

		// alias the location for this
		aliasLoc(null);
	}



	/**
	 * Creates a new BoundingCircle
	 */
	public BoundingCircle(float fRadius_, R2v rLoc_) {
		super(rLoc_, Bounds.CIRCLE);
		setRadius(fRadius_);
		aliasLoc(rLoc_);
	}



	/**
	 * Sets the radius
	 */
	public void setRadius(float fRadius_) {
		m_fRadius = fRadius_;
	}



	/**
	 * Returns the radius
	 */
	public float getRadius() {
		return m_fRadius;
	}



	// determines if there is a collision between this and a point
	@Override
	public boolean isCollision(final R2v rLoc_) {
		R2v test = new R2v();

		test.add(rLoc_);
		test.sub(getLocation());

		return test.lengthSquared() <= (getRadius() * getRadius());
	}



	/**
	 * Determines if there is a collision between this and another object.
	 * 
	 * @since 07-Jul 2006
	 */
	public boolean isCollision(final BoundingCircle rBound_) {
		// if(rBound_ instanceof BoundingCircle)
		// switch(rBound_.getType())
		// {
		// tests a bounding circle
		// case CIRCLE:
		R2v diff;
		diff = new R2v();
		diff.add(this.getLocation());
		diff.sub(rBound_.getLocation());

		float len;
		len = diff.length();

		if (len < (this.getRadius() + (rBound_).getRadius())) {
			return true;
		} else {
			return false;
		}

		// default:
		// return false;
		// }
		// return false;
	}
}