package mako5.math.phys;


import mako5.math.R2v;

/**
 * A bounding rectangle.
 * 
 * 
 * @author Paul Jarrett
 * @version 08-Mar 2006
 * @version 09-Mar 2006
 */

public class BoundingRect extends Bounds {

	private float m_fWidth; // the width of this rectangle

	private float m_fHeight; // the height of this rectangle



	/**
	 * Makes a new Bounding Rectangle.
	 * 
	 * 
	 * @param rLoc_
	 *            the location to alias for this bounding rect
	 * @param fWidth_
	 *            the width of this bounding rect
	 * @param fHeight_
	 *            the height of this bounding rect
	 * @since 08-Mar 2006
	 */
	public BoundingRect(R2v rLoc_, float fWidth_, float fHeight_) {
		super(rLoc_, Bounds.RECT);

		m_fWidth = fWidth_;
		m_fHeight = fHeight_;
	}



	/**
	 * Returns the width of this rectangle.
	 * 
	 * @return the width of this rectangle
	 * @since 08-Mar 2006
	 */
	public float getWidth() {
		return m_fWidth;
	}



	/**
	 * Returns the height of this rectangle.
	 * 
	 * @return the height of this rectangle
	 * @since 08-Mar 2006
	 */
	public float getHeight() {
		return m_fHeight;
	}



	/**
	 * Returns true if this collides with the given point.
	 * 
	 * @param rPoint_
	 *            the point to test this against
	 * @return true if it collides with the given point
	 * @since 08-Mar 2006
	 * @since 09-Mar 2006
	 */
	@Override
	public boolean isCollision(R2v rPoint_) {
		// checks the right and left boundaries
		boolean horizontal = false;

		// checks the upper and lower boundaries
		boolean vertical = false;

		// perform the horizontal checks
		// let's check against the origin position
		horizontal = (getLocation().getX() <= rPoint_.getX());

		// checks against the width of this
		horizontal &= ((getLocation().getX() + m_fWidth) > rPoint_.getX());

		// perform the vertical checks
		// let's check against the origin position
		vertical = (getLocation().getY() <= rPoint_.getY());

		// checks against the height of this
		vertical &= ((getLocation().getY() + m_fHeight) > rPoint_.getY());

		return vertical && horizontal;
	}
}