package mako5.math.phys;


import mako5.math.R2v;

/**
 * Represents the bounds of an object.
 * 
 * @author Paul Jarrett
 * @version 17-Feb 2006
 * @version 09-Mar 2006
 */

public abstract class Bounds {

	public static final int CIRCLE = 0;

	public static final int LINE = 1;

	public static final int RECT = 2;

	public static final int BOUNDARY = 3;

	private R2v m_rLocation; // m_rLocation of this object

	private int m_iType; // type of this



	/**
	 * Creates a new Bounds object.
	 * 
	 * @param iType_
	 *            the ID for the type of this object
	 * 
	 * @since 09-Mar 2006
	 */
	public Bounds(final int iType_) {
		m_rLocation = new R2v();
		m_iType = iType_;
	}



	/**
	 * Creates a new Bounds object.
	 * 
	 * @since 09-Mar 2006
	 */
	public Bounds(final R2v rLoc_, final int iType_) {
		m_rLocation = rLoc_;
		m_iType = iType_;
	}



	/**
	 * Return the type ID of this
	 * 
	 * @since 09-Mar 2006
	 * @deprecated 04-Apr 2006
	 */
	@Deprecated
	public int getType() {
		return m_iType;
	}



	/**
	 * Aliases the given location.
	 * 
	 * Attaches this to the given m_rLocation.
	 * 
	 * @since 09-Mar 2006
	 */
	public final void aliasLoc(final R2v rLoc_) {
		m_rLocation = rLoc_;
	}



	/**
	 * Returns the location this bounds is attached to.
	 * 
	 * @return the aliased location that this bounds is attached to.
	 * @since 09-Mar 2006
	 */
	public R2v getLocation() {
		return m_rLocation;
	}



	/**
	 * Determines if there is a collision between this and a given point
	 * 
	 * @param rLoc_
	 *            the point to test for collision with
	 * @since 09-Mar 2006
	 */
	public abstract boolean isCollision(final R2v rLoc_);



	// //////////////////////////////////////////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////
	// //
	// //
	// //
	// //
	// //
	// //
	// //
	// //
	// //
	// COLLISION PROTOCOLS //
	// //
	// //
	// //
	// //
	// //
	// //
	// //
	// //
	// //
	// //
	// //////////////////////////////////////////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////
	// //////////////////////////////////////////////////////////////////////////

	/**
	 * Tests for collision between a boundary and a bounded rectangle.
	 * 
	 * @param bd
	 *            the boundary
	 * @param rc
	 *            the bounding rect
	 * @since 03-Apr 2006
	 */
	public static boolean testCollision(Boundary bd, BoundingRect rc) {
		if (bd.getWallType() == Boundary.VERTICAL) {
			if (bd.getSolidSide() == Boundary.LEFT) {
				return rc.getLocation().getX() < bd.getLocation().getX();
			} else {
				return rc.getLocation().getX() + rc.getWidth() > bd
						.getLocation().getX();
			}
		} else {
			if (bd.getSolidSide() == Boundary.ABOVE) {
				return rc.getLocation().getY() + rc.getHeight() > bd
						.getLocation().getY();
			} else {
				return rc.getLocation().getY() < bd.getLocation().getY();
			}
		}
	}



	/**
	 * Tests for a collision between a rectangle and another rectangle.
	 * 
	 * @param a
	 *            the first rectangle
	 * @param b
	 *            the second rectangle
	 */
	/*
	 * public static boolean testCollision(inspire.Block a, BoundingRect b) {
	 * float left1 = a.getLocation().getX(); float left2 =
	 * b.getLocation().getX(); float right1 = a.getLocation().getX() +
	 * a.getWidth(); float right2 = b.getLocation().getX() + b.getWidth(); float
	 * top1 = a.getLocation().getY() + a.getHeight(); float top2 =
	 * b.getLocation().getY() + b.getHeight(); float bottom1 =
	 * a.getLocation().getY(); float bottom2 = b.getLocation().getY(); // //
	 * if(a.getLocation().getX() + a.getWidth() < b.getLocation().getX()) return
	 * false; // if(b.getLocation().getX() + b.getWidth() <
	 * a.getLocation().getX()) return false; // if(a.getLocation().getY() +
	 * a.getHeight() > b.getLocation().getY()) return false; //
	 * if(b.getLocation().getY() + b.getHeight() > a.getLocation().getY())
	 * return false;
	 * 
	 * if(top1 < bottom2) return false; if(top2 < bottom1) return false;
	 * if(left2 > right1) return false; if(left1 > right2) return false;
	 * 
	 * return true; }
	 */

	/**
	 * Tests for a collision between a rectangle and another rectangle.
	 * 
	 * @param a
	 *            the first rectangle
	 * @param b
	 *            the second rectangle
	 */
	public static boolean testCollision(BoundingRect a, BoundingRect b) {
		float left1 = a.getLocation().getX();
		float left2 = b.getLocation().getX();
		float right1 = a.getLocation().getX() + a.getWidth();
		float right2 = b.getLocation().getX() + b.getWidth();
		float top1 = a.getLocation().getY() + a.getHeight();
		float top2 = b.getLocation().getY() + b.getHeight();
		float bottom1 = a.getLocation().getY();
		float bottom2 = b.getLocation().getY();
		//
		// if(a.getLocation().getX() + a.getWidth() < b.getLocation().getX())
		// return false;
		// if(b.getLocation().getX() + b.getWidth() < a.getLocation().getX())
		// return false;
		// if(a.getLocation().getY() + a.getHeight() > b.getLocation().getY())
		// return false;
		// if(b.getLocation().getY() + b.getHeight() > a.getLocation().getY())
		// return false;

		return ((bottom1 < top2) && (bottom2 < top1) && (left1 < right2) && (left2 < right1));
		/*
		 * if(top1 < bottom2) return false; if(top2 < bottom1) return false;
		 * if(left2 > right1) return false; if(left1 > right2) return false;
		 * 
		 * return true;
		 */
	}
}