package mako5.tests;


import static org.junit.Assert.*;

import mako5.math.R2v;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
 * @author jarrett
 * 
 */
public class R2vTest {

	/**
	 * Temporary vector used for tests.
	 * 
	 * @since 16-Jul 2006
	 */
	private R2v loc;

	/**
	 * Temporary vector used for tests.
	 * 
	 * @since 16-Jul 2006
	 */
	private R2v loc2;



	/**
	 * @throws java.lang.Exception
	 */
	@Before
	public void setUp() throws Exception {
	}



	/**
	 * @throws java.lang.Exception
	 */
	@After
	public void tearDown() throws Exception {
	}



	/**
	 * Test method for {@link mako5.math.R2v#R2v(float, float)}.
	 */
	@Test
	public final void testR2vFloatFloat() {
		loc = new R2v(1.0f, 4.0f);

		assertEquals(loc.getX(), 1.0f);
		assertEquals(loc.getY(), 4.0f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#R2v(mako5.math.R2v)}.
	 */
	@Test
	public final void testR2vR2v() {
		loc = new R2v(1.0f, 4.0f);
		assertEquals(loc.getX(), 1.0f);
		assertEquals(loc.getY(), 4.0f);

		loc2 = new R2v(loc);
		assertEquals(loc2.getX(), 1.0f);
		assertEquals(loc2.getY(), 4.0f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#R2v()}.
	 */
	@Test
	public final void testR2v() {
		loc = new R2v();
		assertEquals(loc.getX(), 0.0f);
		assertEquals(loc.getY(), 0.0f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#clone()}.
	 */
	@Test
	public final void testClone() {
		loc = new R2v(1.0f, 2.0f);
		assertEquals(loc.getX(), 1.0f);
		assertEquals(loc.getY(), 2.0f);

		assertTrue(loc.clone() instanceof R2v);

		loc2 = (R2v) loc.clone();

		assertEquals(loc.getX(), 1.0f);
		assertEquals(loc.getY(), 2.0f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#set(mako5.math.R2v)}.
	 */
	@Test
	public final void testSetR2v() {

		loc = new R2v(5.0f, 7.0f);

		loc2 = new R2v();
		loc2.set(loc);

		assertEquals(loc2.getX(), 5.0f);
		assertEquals(loc2.getY(), 7.0f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#set(float, float)}.
	 */
	@Test
	public final void testSetFloatFloat() {
		loc = new R2v();

		loc.set(5.0f, 7.0f);

		assertEquals(loc.getX(), 5.0f);
		assertEquals(loc.getY(), 7.0f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#setX(float)}.
	 */
	@Test
	public final void testSetX() {
		loc = new R2v();

		assertFalse(loc.getX() == 17.0f);

		loc.setX(17.0f);

		assertEquals(loc.getX(), 17.0f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#setY(float)}.
	 */
	@Test
	public final void testSetY() {
		loc = new R2v();

		assertFalse(loc.getY() == 17.0f);

		loc.setY(17.0f);

		assertEquals(loc.getY(), 17.0f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#add(float, float)}.
	 */
	@Test
	public final void testAddFloatFloat() {
		loc = new R2v();

		assertEquals(loc.getX(), 0.0f);
		assertEquals(loc.getY(), 0.0f);

		loc.add(3.0f, 5.0f);

		assertEquals(loc.getX(), 3.0f);
		assertEquals(loc.getY(), 5.0f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#add(mako5.math.R2v)}.
	 */
	@Test
	public final void testAddR2v() {
		loc = new R2v(1f,2f);
		loc2 = new R2v(4f,13f);
		
		loc.add(loc2);
		
		assertEquals(loc.getX(),5f);
		assertEquals(loc.getY(),15f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#sub(float, float)}.
	 */
	@Test
	public final void testSubFloatFloat() {
		loc = new R2v();
		
		assertEquals(loc.getX(), 0f);
		assertEquals(loc.getY(), 0f);
		
		loc.sub(3f,4f);
		
		assertEquals(loc.getX(), -3f);
		assertEquals(loc.getY(), -4f);
		
	}



	/**
	 * Test method for {@link mako5.math.R2v#sub(mako5.math.R2v)}.
	 */
	@Test
	public final void testSubR2v() {
		loc = new R2v(1f,2f);
		loc2 = new R2v(4f,13f);
		
		loc.sub(loc2);
		
		assertEquals(loc.getX(),-3f);
		assertEquals(loc.getY(),-11f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#multi(float)}.
	 */
	@Test
	public final void testMulti() {
		loc = new R2v(1f,2f);
		
		loc.multi(4f);
		
		assertEquals(loc.getX(),4f);
		assertEquals(loc.getY(),8f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#div(float)}.
	 */
	@Test
	public final void testDiv() {
		loc = new R2v(4f,8f);
		
		loc.div(4f);
		
		assertEquals(loc.getX(),1f);
		assertEquals(loc.getY(),2f);
		
	}



	/**
	 * Test method for {@link mako5.math.R2v#normalize()}.
	 */
	@Test
	public final void testNormalize() {
		loc = new R2v(0f,0f);
		
		assertEquals(loc.length(),0f);
		
		loc = new R2v(2f,0f);
		assertEquals(loc.length(),2f);
		
		loc = new R2v(0f,2f);
		assertEquals(loc.length(), 2f);
		
		loc = new R2v(3f,4f);
		assertEquals(loc.length(), 5f);
	}



	/**
	 * Test method for {@link mako5.math.R2v#findDistanceTo(mako5.math.R2v)}.
	 */
	@Test
	public final void testFindDistanceTo() {
		fail("Not yet implemented"); // TODO
	}



	/**
	 * Test method for {@link mako5.math.R2v#angleWith(mako5.math.R2v)}.
	 */
	@Test
	public final void testAngleWith() {
		fail("Not yet implemented"); // TODO
	}



	/**
	 * Test method for {@link mako5.math.R2v#lengthSquared()}.
	 */
	@Test
	public final void testLengthSquared() {
		fail("Not yet implemented"); // TODO
	}



	/**
	 * Test method for {@link mako5.math.R2v#length()}.
	 */
	@Test
	public final void testLength() {
		fail("Not yet implemented"); // TODO
	}



	/**
	 * Test method for {@link mako5.math.R2v#hasHat()}.
	 */
	@Test
	public final void testHasHat() {
		loc = new R2v(0f,0f);
		assertEquals(0f, loc.length());
		assertFalse(loc.hasHat());
		
		loc = new R2v(1f,0f);
		assertEquals(1f, loc.length());
		assertTrue(loc.hasHat());
	}



	/**
	 * Test method for {@link mako5.math.R2v#setLength(float)}.
	 */
	@Test
	public final void testSetLength() {
		loc = new R2v(0f,0f);
		
		//TODO will have problem when has no length to begin with
		
		loc = new R2v(1f,0f);
		loc.setLength(5f);
		
		assertEquals(5f,loc.length());
		loc = new R2v(0f,1f);
		loc.setLength(5f);
		assertEquals(5f,loc.length());
		
		loc = new R2v(2f,5f);
		loc.setLength(5f);
		assertEquals(5f,loc.length());
	}



	/**
	 * Test method for {@link mako5.math.R2v#dot(mako5.math.R2v)}.
	 */
	@Test
	public final void testDot() {
		fail("Not yet implemented"); // TODO
	}



	/**
	 * Test method for {@link mako5.math.R2v#getDirection()}.
	 */
	@Test
	public final void testGetDirection() {
		fail("Not yet implemented"); // TODO
	}



	/**
	 * Test method for {@link mako5.math.R2v#toPolar()}.
	 */
	@Test
	public final void testToPolar() {
		fail("Not yet implemented"); // TODO
	}



	/**
	 * Test method for {@link mako5.math.R2v#toString()}.
	 */
	@Test
	public final void testToString() {
		fail("Not yet implemented"); // TODO
	}
}
