package mako5.util;


/**
 * An array stack that may not be expanded.
 * 
 * @author Paul Jarrett
 * @version 14-Mar 2006
 * @version 24-Mar 2006 (1.00)
 */

public final class ArrayStack<T> implements Stack<T> {

	/**
	 * The contents of this stack.
	 * 
	 * @since 14-Mar 2006
	 */
	private T[] contents;

	/**
	 * The index of where the next element will be added.
	 * 
	 * @since 14-Mar 2006
	 */
	private int count;



	/**
	 * Makes a new stack with the given capacity.
	 * 
	 * @param iCapacity_
	 *            the desired capacity for the stack
	 * @since 14-Mar 2006
	 * @since 24-Mar 2006 (1.00)
	 */
	public ArrayStack(final int iCapacity_) {
		
		// makes the storage array
		contents = (T[]) (new Object[iCapacity_]);
		
		// the next element will be added after the last element
		// in the stack, since be don't start with any elements
		// the first element will be put at position 0
		count = 0;
	}



	/**
	 * Pushes an element into the stack.
	 * 
	 * @param rVal_
	 *            the element to add into the stack
	 * @since 14-Mar 2006
	 * @since 24-Mar 2006 (1.00)
	 */
	public void push(T rVal_) {
		// checks to see that the stack is not full
		assert (count < contents.length);

		// adds the element
		contents[count] = rVal_;

		// increments the counter
		count++;
	}



	/**
	 * Pops an element from this stack.
	 * 
	 * @return the popped element from this stack
	 * @since 14-Mar 2006
	 * @since 24-Mar 2006 (1.00)
	 */
	public T pop() {
		// checks to see that the stack is not empty
		assert (!isEmpty());

		// gets the value to return
		T rVal = contents[count - 1];

		// deletes the object from the array
		contents[count - 1] = null;

		// updates the count on elements
		count--;

		// returns the popped value
		return rVal;
	}



	/**
	 * Returns true if this stack is empty.
	 * 
	 * @return true if this stack is empty.
	 * @since 14-Mar 2006
	 * @since 24-Mar 2006 (1.00)
	 */
	public boolean isEmpty() {
		return count == 0;
	}



	/**
	 * Returns the current number of elements in this stack.
	 * 
	 * @return the number of elements in the stack.
	 * @since 14-Mar 2006
	 */
	public int size() {
		return count;
	}



	/**
	 * Returns the maximum capacity for this stack.
	 * 
	 * @return the most number of elements that this stack can hold
	 * @since 29-Jun 2006
	 */
	public int getCapacity() {
		return contents.length;
	}
}