package mako5.util;


import java.util.Random;

/**
 * Provides a generic random generator to pull from.
 * 
 * @author Paul Jarrett
 * @version 03-Mar 2006
 * @version 24-May 2006
 */

public class RandomGen {

	/**
	 * the instance of Random for this
	 */
	private static Random INSTANCE;



	/**
	 * Sets the random generator instance.
	 * 
	 * @throws SingletonException
	 *             if it attempts to override a previous singleton instance
	 * @since 03-Mar 2006
	 * @since 24-May 2006
	 */
	private static void makeInstance() {
		// will not override a previous instance
		if (INSTANCE != null) {
			throw new RuntimeException(
					"Attempting to override previous singleton instance");
		} else {
			// makes a new Random object
			INSTANCE = new Random();
		}
	}



	/**
	 * Returns true if this has a current instance.
	 * 
	 * @return true if this has an instance of Random.
	 * @since 03-Mar 2006
	 */
	public static boolean hasInstance() {
		return (INSTANCE != null);
	}



	/**
	 * Returns the current random generator instance.
	 * 
	 * @return the instance of this Random singleton
	 * @since 03-Mar 2006
	 */
	public static Random getInstance() {
		// makes sure that we have an instance
		if (!hasInstance()) {
			makeInstance();
		}

		// returns the current random instance
		return INSTANCE;
	}
}